> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #TouchPad click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example
```
#include "touchpad_hw.h"
#include "resources.h"
#include "gesture.h"

/*******************************************************************************
* TFT module connections
*******************************************************************************/
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8; 
sbit TFT_RS at GPIOE_ODR.B12; 
sbit TFT_CS at GPIOE_ODR.B15; 
sbit TFT_RD at GPIOE_ODR.B10; 
sbit TFT_WR at GPIOE_ODR.B11; 
sbit TFT_BLED at GPIOE_ODR.B9; 
sbit MTCH6102_RDY at GPIOD_IDR.B10; 
sbit MTCH6102_RST at GPIOC_ODR.B2; 
char gesture_event, gesture_event_old; 
touch_point position_x_y; 
unsigned int hold_cnt, color, cnt;
char text[16];

/*******************************************************************************
* Display init
*******************************************************************************/
static void Display_Init()
{
    TFT_Init_ILI9341_8bit( 320, 240 );
    color = TFT_RGBToColor16bit(000,221, 210);
    TFT_Set_Font( TFT_defaultFont, CL_WHITE, FO_HORIZONTAL );
    TFT_Fill_Screen( CL_WHITE );
    TFT_Set_Brush(1, CL_WHITE , 0, 0, 0, 0);
    TFT_Set_Pen( CL_BLUE, 1 );
    TFT_Line( 20, 220, 300, 220 );
    TFT_LIne( 20,  40, 300,  40 );
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_BLUE, FO_HORIZONTAL );
    TFT_Write_Text( "TouchPad click", 90, 10 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_BLUE, FO_HORIZONTAL );
    TFT_Write_Text( "EasyMx PRO v7 for STM32", 19, 223 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "www.mikroe.com", 200, 223 );
    //TFT_Set_Font( &TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
    //TFT_Write_Text( "GESTURE EVENT: ", 20, 100 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_BLUE, FO_HORIZONTAL );
    TFT_Write_Text( "Position X: ", 20, 200 );
    TFT_Write_Text( "Position Y: ", 215, 200 );
    TFT_Set_Font( &TFT_defaultFont, CL_RED, FO_HORIZONTAL );
    TFT_Rectangle( 80, 60, 300, 180 );
    TFT_Write_Text( "Please wait...", 100, 110 );
    
}

/******************************************************************************
* Timer2 Prescaler :119; Preload = 59999; Actual Interrupt Time = 100 ms
*******************************************************************************/
#if defined( __MIKROC_PRO_FOR_ARM__ )
void InitTimer2()
{
    RCC_APB1ENR.TIM2EN = 1;
    TIM2_CR1.CEN = 0;
    TIM2_PSC = 119;
    TIM2_ARR = 59999;
    NVIC_IntEnable( IVT_INT_TIM2 );
    TIM2_DIER.UIE = 1;
    TIM2_CR1.CEN = 1;
}

void Timer2_interrupt() iv IVT_INT_TIM2
{
    TIM2_SR.UIF = 0;
    if ( gesture_event != 0 )
        hold_cnt++;
}
#endif

/******************************************************************************
* Display event
*******************************************************************************/
static void Display_Event()
{
    TFT_Set_Font( &TFT_defaultFont, CL_RED, FO_HORIZONTAL );
    TFT_Rectangle( 80, 60, 300, 180 );
    switch ( gesture_event )
    {
        case CLICK_AND_HOLD:
            TFT_Image(110,80, touch_hold_bmp, 1);
            break;
        case DOUBLE_CLICK:
            TFT_Image(110,80, touch_double_bmp, 1);
            break;
        case SINGLE_CLICK:
            TFT_Image(110,80, touch_single_bmp, 1);
            break;
        case DOWN_SWIPE:
            TFT_Image(110,80, touch_up_bmp, 1);
            break;
        case DOWN_SWIPE_AND_HOLD:
            TFT_Image(110,80, touch_up_bmp, 1);
            break;
        case RIGHT_SWIPE:
            TFT_Image(110,80, touch_left_bmp, 1);
            break;
        case RIGHT_SWIPE_AND_HOLD:
            TFT_Image(110,80, touch_left_bmp, 1);
            break;
        case UP_SWIPE:
            TFT_Image(110,80, touch_down_bmp, 1);
            break;
        case UP_SWIPE_AND_HOLD:
            TFT_Image(110,80, touch_down_bmp, 1);
            break;
        case LEFT_SWIPE:
            TFT_Image(110,80, touch_right_bmp, 1);
            break;
        case LEFT_SWIPE_AND_HOLD:
            TFT_Image(110,80, touch_right_bmp, 1);
            break;
        default:
            TFT_Write_Text( "NO GESTURE PRESENT", 100, 110 );
            asm nop;
    }
}

/*******************************************************************************
* Display position
*******************************************************************************/
static void Display_Position()
{
    TFT_Rectangle( 80, 200, 110, 210 );
    TFT_Rectangle( 275, 200, 300, 210 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_BLUE, FO_HORIZONTAL );
    WordToSTr( position_x_y.posX, text );
    TFT_Write_Text( text, 80, 200 );
    WordToSTr( position_x_y.posY, text );
    TFT_Write_Text( text, 275, 200 );
}

/*******************************************************************************
* System init
*******************************************************************************/
static void system_init()
{
    GPIO_Digital_Input( &GPIOD_BASE, _GPIO_PINMASK_10 );
    GPIO_Digital_Output( &GPIOC_BASE, _GPIO_PINMASK_2 );
    I2C1_Init_Advanced( 100000, &_GPIO_MODULE_I2C1_PB67 );
    delay_ms( 100 );
    Display_Init();
    MTCH6102_RST = 1;
    delay_ms( 100 );
    MTCH6102_RST = 0;
    delay_ms( 100 );
    MTCH6102_RST = 1;
    delay_ms( 100 );
    mtch6102_init( MTCH6102_I2C_ADR );
    delay_ms( 150 );
    TFT_Rectangle( 80, 60, 300, 180 );
    TFT_Write_Text( "NO GESTURE PRESENT", 100, 110 );
    Display_Event();
    Display_Position();
    mtch6102_set_mode( FULL );
    InitTimer2();
}

/******************************************************************************
* New gesture event
*******************************************************************************/
void new_gesture_event()
{
    Display_Event();
    gesture_event_old = gesture_event;
    hold_cnt = 0;
}
```

```
/******************************************************************************
* Main program
*******************************************************************************/
void main()
{
    system_init();
    gesture_event = 0;
    gesture_event_old = gesture_event;

    while( 1 )
    {
        while( MTCH6102_RDY )
        {
            if ( hold_cnt > 19 )
            {
                gesture_event = 0;
                gesture_event_old = gesture_event;
                hold_cnt = 0;
                Display_Event();
            }
        }

        gesture_event = mtch6102_get_gesture_state();
        if ( gesture_event != gesture_event_old ) new_gesture_event();

        position_x_y = mtch6102_get_position();
        Display_Position();

        delay_ms( 100 );
    }
}
```